@@ -29,6 +29,7 @@ class Runner(msgspec.Struct):
     status: Optional[str] = None
     adjustmentFactor: Optional[float] = None
     selectionId: Optional[str] = None
+    bsp: Optional[float] = None
 
     @property
     def handicap(self) -> str:
@@ -39,7 +40,7 @@ class Runner(msgspec.Struct):
         return int(self.selectionId or self.id)
 
 
-class MarketDefinition(msgspec.Struct, kw_only=True):  # type: ignore
+class MarketDefinition(msgspec.Struct, kw_only=True):
     """
     https://docs.developer.betfair.com/display/1smk3cen4v3lu3yomq5qye0ni/Exchange+Stream+API
     """
@@ -153,8 +154,10 @@ class RunnerChange(msgspec.Struct):
     batl: Optional[List[BestAvailableToLay]] = []
     bdatb: Optional[List[BestDisplayAvailableToBack]] = []
     bdatl: Optional[List[BestDisplayAvailableToLay]] = []
-    spb: Optional[List[StartingPriceBack]] = []
-    spl: Optional[List[StartingPriceLay]] = []
+    spb: Optional[List[StartingPriceBack]] = []  # Starting Price (Available To) Back
+    spl: Optional[List[StartingPriceLay]] = []  # Starting Price (Available To) Lay
+    spn: Optional[Union[float, str]] = None  # Starting Price Near
+    spf: Optional[Union[int, float, str]] = None  # Starting Price Far
     trd: Optional[List[Trade]] = []
     ltp: Optional[float] = None
     tv: Optional[float] = None
@@ -174,7 +177,7 @@ class MarketChange(msgspec.Struct):
     con: Optional[bool] = None
 
 
-class MCM(msgspec.Struct, tag_field="op", tag=str.lower):  # type: ignore
+class MCM(msgspec.Struct, tag_field="op", tag=str.lower):
     """
     https://docs.developer.betfair.com/display/1smk3cen4v3lu3yomq5qye0ni/Exchange+Stream+API
     """
